@@ -1,4 +1,4 @@
 from .client import Client
 from .obi import PyObi
+from .wallet import PrivateKey, PublicKey, Address, Wallet
 from .transaction import Transaction
-from .wallet import PrivateKey, PublicKey, Address
